pub struct Plumber {
pub notification_queue_interval: u64,
pub notification_queue_max_age: u64,
pub enable_task_cleanup: bool,
pub task_cleanup_user: Option<String>,
pub task_cleanup_password: Option<String>,
}Expand description
Plumber Configuration
Fields
notification_queue_interval: u64Interval in seconds at which the notification queue cleanup should run
notification_queue_max_age: u64Max age in seconds notification queue messages can be
enable_task_cleanup: boolShould rust run cleanup of elasticsearch’s .tasks table
task_cleanup_user: Option<String>If task cleanup is enabled what user to use for that task (if not set a user will be created) The task_cleanup_password must also be set.
task_cleanup_password: Option<String>Password for the task cleanup user, in kubernetes deployments should probably be set to an environment variable defined in coreEnv where the password is being set from a secret.