pub struct Services {
pub stages: Vec<String>,
pub preferred_update_channel: String,
pub allow_insecure_registry: bool,
pub preferred_registry_type: RegistryTypes,
pub prefer_service_privileged: bool,
pub cpu_reservation: f64,
pub safelist: ServiceSafelist,
}Expand description
Services Configuration
Fields
stages: Vec<String>List of execution stages a service can be assigned to
preferred_update_channel: StringSubstitution variables for image paths (for custom registry support)
Similar to image_variables but only applied to the updater. Intended for use with local registries.
Default update channel to be used for new services
allow_insecure_registry: boolAllow fetching container images from insecure registries
preferred_registry_type: RegistryTypesGlobal registry type to be used for fetching updates for a service (overridable by a service)
prefer_service_privileged: boolGlobal preference that controls if services should be privileged to communicate with core infrastucture
cpu_reservation: f64How much CPU do we want to reserve relative to the service’s request?
At 1, a service’s full CPU request will be reserved for them.
At 0 (only for very small appliances/dev boxes), the service’s CPU will be limited ““but no CPU will be reserved allowing for more flexible scheduling of containers.
safelist: ServiceSafelistTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Services
impl<'de> Deserialize<'de> for Services
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,