pub struct Plumber {
pub notification_queue_interval: u64,
pub notification_queue_max_age: u64,
}Expand description
Plumber Configuration
Fields
notification_queue_interval: u64Interval in seconds at which the notification queue cleanup should run
notification_queue_max_age: u64Max age in seconds notification queue messages can be